#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_maintained, :parent => ::Puppet_X::EnterpriseModules::Oracle::ReadOnlyProperty) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Information

  desc <<-EOD
    This is a read only property that cannot be used when specifying a user.
  EOD

  def insync?(is)
    true    # This is a readonly property
  end

  data_type("Variant[Boolean,Enum['n/a']]")

  to_translate_to_resource do |raw_resource|
    #
    # First get the value from the raw resource. If 'ORACLE_MAINTAINED' is filled
    # it means we are on Oracle 12 or higher and we can show the property.
    #
    sid = raw_resource['SID']
    case raw_resource['ORACLE_MAINTAINED']
    when nil then 'n/a'
    when 'N' then :false
    when 'Y' then :true
    else
      fail 'invalid value received from column ORACLE_MAINTAINED'
    end
  end

  on_create do
    fail 'Usage of the oracle_maintained property not allowed'
  end

  on_modify do
    fail 'Modification of the oracle_maintained property not allowed'
  end

end
